==> u_team_core-common-1.20.1-5.1.4.336-sources.jar: info/u_team/u_team_core/integration/jei/UTeamCoreJeiPlugin.java <==
package info.u_team.u_team_core.integration.jei;

import java.util.List;
import java.util.stream.Collectors;

import info.u_team.u_team_core.UCoreReference;
import info.u_team.u_team_core.api.dye.DyeableItem;
import info.u_team.u_team_core.inventory.DummyCraftingContainer;
import info.u_team.u_team_core.util.RegistryUtil;
import mezz.jei.api.IModPlugin;
import mezz.jei.api.JeiPlugin;
import mezz.jei.api.constants.VanillaTypes;
import mezz.jei.api.registration.IRecipeRegistration;
import net.minecraft.class_1768;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3956;
import net.minecraft.class_638;
import net.minecraft.class_7924;

@JeiPlugin
public class UTeamCoreJeiPlugin implements IModPlugin {
	
	private final class_2960 id = new class_2960(UCoreReference.MODID, "jei");
	
	@Override
	public class_2960 getPluginUid() {
		return id;
	}
	
	@Override
	public void registerRecipes(IRecipeRegistration registration) {
		final class_638 level = class_310.method_1551().field_1687;
		
		final DummyCraftingContainer container = new DummyCraftingContainer(3, 3);
		
		container.method_5447(1, new class_1799(class_1802.field_8446));
		
		final List<class_1799> items = RegistryUtil.getBuiltInRegistry(class_7924.field_41197).method_10220() //
				.filter(item -> item instanceof DyeableItem || item instanceof class_1768) //
				.map(class_1799::new) //
				.filter(stack -> {
					container.method_5447(0, stack.method_7972());
					return level.method_8433().method_8132(class_3956.field_17545, container, level).isPresent();
				}).collect(Collectors.toList());
		
		registration.addIngredientInfo(items, VanillaTypes.ITEM_STACK, class_2561.method_43471("jei.uteamcore.dyeable.info"));
	}
	
}

==> u_team_core-common-1.20.6-5.4.0.363-sources.jar: info/u_team/u_team_core/integration/jei/UTeamCoreJeiPlugin.java <==
package info.u_team.u_team_core.integration.jei;

import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;

import info.u_team.u_team_core.UCoreReference;
import info.u_team.u_team_core.inventory.DummyCraftingContainer;
import info.u_team.u_team_core.util.RegistryUtil;
import mezz.jei.api.IModPlugin;
import mezz.jei.api.JeiPlugin;
import mezz.jei.api.constants.VanillaTypes;
import mezz.jei.api.registration.IRecipeRegistration;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3489;
import net.minecraft.class_3956;
import net.minecraft.class_638;
import net.minecraft.class_7924;

@JeiPlugin
public class UTeamCoreJeiPlugin implements IModPlugin {
	
	private final class_2960 id = new class_2960(UCoreReference.MODID, "jei");
	
	@Override
	public class_2960 getPluginUid() {
		return id;
	}
	
	@Override
	public void registerRecipes(IRecipeRegistration registration) {
		final class_638 level = class_310.method_1551().field_1687;
		
		final DummyCraftingContainer container = new DummyCraftingContainer(3, 3);
		
		container.method_5447(1, new class_1799(class_1802.field_8446));
		
		final List<class_1799> items = StreamSupport.stream(RegistryUtil.getBuiltInRegistry(class_7924.field_41197).method_40286(class_3489.field_48803).spliterator(), false) //
				.map(class_1799::new) //
				.filter(stack -> {
					container.method_5447(0, stack);
					return level.method_8433().method_8132(class_3956.field_17545, container, level).isPresent();
				}).collect(Collectors.toList());
		
		if (!items.isEmpty()) {
			registration.addIngredientInfo(items, VanillaTypes.ITEM_STACK, class_2561.method_43471("jei.uteamcore.dyeable.info"));
		}
	}
	
}
